@@ -7,7 +7,7 @@ import logging
 nlp = spacy.load('en_core_web_sm', exclude=['tagger', 'parser', 'attribute_ruler', 'lemmatizer', 'ner',])
 
 # TODO: Fix the add_special_case, current method doesn't work
-nlp.tokenizer.from_disk('carsomenlp/artefacts/tokenizer')
+nlp.tokenizer.from_disk('src/carsomenlp/artefacts/tokenizer')
 
 # To uncomment if need more deeper NLP use case
 # @Language.component("custom_parser")
